@@ -144,13 +144,10 @@ typedef struct _typeobject {
 
 // PYSIDE-1797: This must be a runtime decision.
 //              Remove that when the minimum Python version is 3.8,
-//              because the macro PepIndex_Check bug was fixed then.
-/// FIXME: Remove PepIndex_Check and pep384_issue33738.cpp when Python 3.7 is gone.
-LIBSHIBOKEN_API int PepIndex_Check(PyObject *obj);
-
-#else // Py_LIMITED_API
-
-#define PepIndex_Check(obj)               PyIndex_Check(obj)
+//              because the macro PyIndex_Check bug was fixed then.
+/// FIXME: Remove PyIndex_Check and pep384_issue33738.cpp when Python 3.7 is gone.
+#undef PyIndex_Check
+LIBSHIBOKEN_API int PyIndex_Check(PyObject *obj);
 
 #endif // Py_LIMITED_API
 
@@ -186,6 +183,8 @@ LIBSHIBOKEN_API const char *PepType_GetNameStr(PyTypeObject *type);
  */
 #ifdef Py_LIMITED_API
 LIBSHIBOKEN_API int _PepLong_AsInt(PyObject *);
+#elif PY_VERSION_HEX >= 0x030D0000
+#define _PepLong_AsInt PyLong_AsInt
 #else
 #define _PepLong_AsInt _PyLong_AsInt
 #endif
@@ -570,6 +569,14 @@ extern LIBSHIBOKEN_API PyObject *PepMapping_Items(PyObject *o);
 
 extern LIBSHIBOKEN_API int PepRuntime_38_flag;
 
+/*****************************************************************************
+ *
+ * Runtime support for Python 3.12 incompatibility
+ *
+ */
+
+LIBSHIBOKEN_API PyObject *PepType_GetDict(PyTypeObject *type);
+
 /*****************************************************************************
  *
  * Module Initialization
